<?php
namespace XLite\Module\Foridev\TrustPay\Controller\Customer;

class TrustPay extends \XLite\Controller\Customer\ACustomer implements \XLite\Base\IDecorator {

    protected function doActionGetUrl()
    {
        header('Content-Type: application/json');

        $cart = $this->getCart();

        $payment = $this->getPaymentMethod()->getProcessor();
        $payment->getUrl($cart);
    }

    protected function doActionError() {
        $error = 'Failed';

        if($this->getTrustPayTranslation(\XLite\Core\Request::getInstance()->AcquirerResponseId)) {
            $error = $this->getTrustPayTranslation(\XLite\Core\Request::getInstance()->AcquirerResponseId);
        } elseif ($this->getTrustPayTranslation(\XLite\Core\Request::getInstance()->ResultCode)) {
            $error = $this->getTrustPayTranslation(\XLite\Core\Request::getInstance()->ResultCode);
        }

        \XLite\Core\TopMessage::addError($error);

        $checkout = \XLite::getInstance()->getShopURL(
            \XLite\Core\Converter::buildURL('checkout', '', array(), \XLite::getCustomerScript()),
            \XLite\Core\Config::getInstance()->Security->customer_security
        );

        header('location: ' . $checkout);
        exit;
    }

    protected function getPaymentMethod()
    {
        return \XLite\Core\Database::getRepo('XLite\Model\Payment\Method')
            ->findOneBy(array('service_name' => 'TrustPay'));
    }

    protected function getTrustPayTranslation($text) {
        $translate = '';

        $locale = $this->getPaymentMethod()->getSetting('locale');

        $data = array(
            '100.100.303' => array(
                'en' => 'Rejected - card expired',
                'sk' => 'Odmietnuté – expirovaná karta',
                'cs' => 'Odmítnuto – expirovaná karta'
            ),
            '100.100.600' => array(
                'en' => 'Rejected - invalid CVV',
                'sk' => 'Odmietnuté – neplatné CVV',
                'cs' => 'Odmítnuto – neplatné CVV'
            ),
            '100.100.601' => array(
                'en' => 'Rejected - invalid CVV',
                'sk' => 'Odmietnuté – neplatné CVV',
                'cs' => 'Odmítnuto – neplatné CVV'
            ),
            '100.100.700' => array(
                'en' => 'Rejected - invalid card number',
                'sk' => 'Odmietnuté – neplatné číslo karty',
                'cs' => 'Odmítnuto – neplatné číslo karty'
            ),
            '100.380.401' => array(
                'en' => 'Rejected - failed 3DS authentication',
                'sk' => 'Odmietnuté – neúspešná 3DS autentifikácia',
                'cs' => 'Odmítnuto – neúspěšná 3DS autentifikace'
            ),
            '100.380.501' => array(
                'en' => 'Rejected - failed 3DS authentication',
                'sk' => 'Odmietnuté – neúspešná 3DS autentifikácia',
                'cs' => 'Odmítnuto – neúspěšná 3DS autentifikace'
            ),
            '800.100.151' => array(
                'en' => 'Rejected - invalid card number',
                'sk' => 'Odmietnuté – neplatné číslo karty',
                'cs' => 'Odmítnuto – neplatné číslo karty'
            ),
            '800.100.153' => array(
                'en' => 'Rejected - invalid CVV',
                'sk' => 'Odmietnuté – neplatné CVV',
                'cs' => 'Odmítnuto – neplatné CVV'
            ),
            '800.100.155' => array(
                'en' => 'Rejected - insufficient funds',
                'sk' => 'Odmietnuté – nedostatočné prostriedky',
                'cs' => 'Odmítnuto – nedostatečné prostředky'
            ),
            '800.100.157' => array(
                'en' => 'Rejected - invalid expiry date',
                'sk' => 'Odmietnuté – neplatný dátum expirácie',
                'cs' => 'Odmítnuto – neplatné datum expirace'
            ),
            '800.100.161' => array(
                'en' => 'Rejected - too many invalid tries',
                'sk' => 'Odmietnuté – priveľa neplatných pokusov',
                'cs' => 'Odmítnuto – příliš mnoho neplatných pokusú'
            ),
            '800.100.162' => array(
                'en' => 'Rejected - card limit exceeded',
                'sk' => 'Odmietnuté – prekročený limit karty',
                'cs' => 'Odmítnuto – překročení limitu karty'
            ),
            '800.100.163' => array(
                'en' => 'Rejected - card limit exceeded',
                'sk' => 'Odmietnuté – prekročený limit karty',
                'cs' => 'Odmítnuto – překročení limitu karty'
            ),
            '800.120.101' => array(
                'en' => 'Rejected - card limit exceeded',
                'sk' => 'Odmietnuté – prekročený limit karty',
                'cs' => 'Odmítnuto – překročení limitu karty'
            ),
            '800.120.200' => array(
                'en' => 'Rejected - card limit exceeded',
                'sk' => 'Odmietnuté – prekročený limit karty',
                'cs' => 'Odmítnuto – překročení limitu karty'
            ),
            '800.120.201' => array(
                'en' => 'Rejected - card limit exceeded',
                'sk' => 'Odmietnuté – prekročený limit karty',
                'cs' => 'Odmítnuto – překročení limitu karty'
            ),
            '1001' => array(
                'en' => 'Some of the parameters in request are missing or have invalid format',
                'sk' => 'Some of the parameters in request are missing or have invalid format',
                'cs' => 'Some of the parameters in request are missing or have invalid format'
            ),
            '1002' => array(
                'en' => 'Account with specified ID was not found. Please check that you are using correct AID for playground/live environment.',
                'sk' => 'Account with specified ID was not found. Please check that you are using correct AID for playground/live environment.',
                'cs' => 'Account with specified ID was not found. Please check that you are using correct AID for playground/live environment.'
            ),
            '1003' => array(
                'en' => 'Merchant account has been disabled',
                'sk' => 'Merchant account has been disabled',
                'cs' => 'Merchant account has been disabled'
            ),
            '1004' => array(
                'en' => 'Verification of request signature has failed',
                'sk' => 'Verification of request signature has failed',
                'cs' => 'Verification of request signature has failed'
            ),
            '1005' => array(
                'en' => 'Customer has cancelled the payment',
                'sk' => 'Customer has cancelled the payment',
                'cs' => 'Customer has cancelled the payment'
            ),
            '1006' => array(
                'en' => 'Request was not properly authenticated',
                'sk' => 'Request was not properly authenticated',
                'cs' => 'Request was not properly authenticated'
            ),
            '1007' => array(
                'en' => 'Requested transaction amount is greater than disposable balance',
                'sk' => 'Requested transaction amount is greater than disposable balance',
                'cs' => 'Requested transaction amount is greater than disposable balance'
            ),
            '1008' => array(
                'en' => 'Service cannot be used or permission to use given service has not been granted. If you receive this code, please contact Trust Pay for more information.',
                'sk' => 'Service cannot be used or permission to use given service has not been granted. If you receive this code, please contact Trust Pay for more information.',
                'cs' => 'Service cannot be used or permission to use given service has not been granted. If you receive this code, please contact Trust Pay for more information.'
            ),
            '1009' => array(
                'en' => 'Specified processing ID was already used. Please generate a new PID using Setup payment service call.',
                'sk' => 'Specified processing ID was already used. Please generate a new PID using Setup payment service call.',
                'cs' => 'Specified processing ID was already used. Please generate a new PID using Setup payment service call.'
            ),
            '1010' => array(
                'en' => 'Transaction with specified ID was not found',
                'sk' => 'Transaction with specified ID was not found',
                'cs' => 'Transaction with specified ID was not found'
            ),
            '1011' => array(
                'en' => 'The requested action is not supported for the transaction',
                'sk' => 'The requested action is not supported for the transaction',
                'cs' => 'The requested action is not supported for the transaction'
            ),
            '1014' => array(
                'en' => 'Transaction was rejected by issuer',
                'sk' => 'Transaction was rejected by issuer',
                'cs' => 'Transaction was rejected by issuer'
            ),
            '1100' => array(
                'en' => 'Internal error has occurred. Please contact Trust Pay to resolve this issue.',
                'sk' => 'Internal error has occurred. Please contact Trust Pay to resolve this issue.',
                'cs' => 'Internal error has occurred. Please contact Trust Pay to resolve this issue.'
            ),
            '1101' => array(
                'en' => 'Currency conversion for requested currencies is not supported',
                'sk' => 'Currency conversion for requested currencies is not supported',
                'cs' => 'Currency conversion for requested currencies is not supported'
            ),

        );

        if(isset($data[$text]) && isset($data[$text][$locale])) {
            $translate = $data[$text][$locale];
        }

        return $translate;
    }
}